@@ -45,7 +45,8 @@ public:
   QString defaultValue() const override;
   void setValue(const QString &) override;
   void reset() override;
-  bool initFromText(const char * text, int & textLength) override;
+  void randomize() override;
+  bool initFromText(const QString & filterName, const char * text, int & textLength) override;
 public slots:
   void onComboBoxIndexChanged(int);
 
