@@ -27,6 +27,7 @@
 #include <QDesktopServices>
 #include <QGridLayout>
 #include <QLabel>
+#include <QRegularExpression>
 #include <QString>
 #include <QUrl>
 #include "Common.h"
@@ -58,7 +59,8 @@ bool LinkParameter::addTo(QWidget * widget, int row)
   _label->setAlignment(_alignment);
   _label->setTextFormat(Qt::RichText);
   _label->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
-  connect(_label, SIGNAL(linkActivated(QString)), this, SLOT(onLinkActivated(QString)));
+  setTextSelectable(_label);
+  connect(_label, &QLabel::linkActivated, this, &LinkParameter::onLinkActivated);
   _grid->addWidget(_label, row, 0, 1, 3);
   return true;
 }
@@ -77,7 +79,7 @@ void LinkParameter::setValue(const QString &) {}
 
 void LinkParameter::reset() {}
 
-bool LinkParameter::initFromText(const char * text, int & textLength)
+bool LinkParameter::initFromText(const QString & filterName, const char * text, int & textLength)
 {
   QList<QString> list = parseText("link", text, textLength);
   if (list.isEmpty()) {
@@ -104,12 +106,12 @@ bool LinkParameter::initFromText(const char * text, int & textLength)
   }
 
   if (values.size() == 2) {
-    _text = values[0].trimmed().remove(QRegExp("^\"")).remove(QRegExp("\"$"));
-    _text = HtmlTranslator::html2txt(FilterTextTranslator::translate(_text));
+    _text = values[0].trimmed().remove(QRegularExpression("^\"")).remove(QRegularExpression("\"$"));
+    _text = HtmlTranslator::html2txt(FilterTextTranslator::translate(_text, filterName));
     values.pop_front();
   }
   if (values.size() == 1) {
-    _url = values[0].trimmed().remove(QRegExp("^\"")).remove(QRegExp("\"$"));
+    _url = values[0].trimmed().remove(QRegularExpression("^\"")).remove(QRegularExpression("\"$"));
   }
   if (values.isEmpty()) {
     return false;
